# Rinokeras

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/5e5663d0c80240a8a05a44a5e6df0ad6)](https://www.codacy.com/app/DavidMChan/rinokeras?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=CannyLab/rinokeras&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/CannyLab/rinokeras/branch/mvr/graph/badge.svg)](https://codecov.io/gh/CannyLab/rinokeras)
[![Build Status](https://travis-ci.org/CannyLab/rinokeras.svg?branch=develop)](https://travis-ci.org/CannyLab/rinokeras)
[![Docs Status](https://readthedocs.org/projects/rinokeras/badge/?version=latest)](https://rinokeras.readthedocs.io/en/latest/)

### Documentation

Read our docs: https://rinokeras.readthedocs.io/en/latest/index.html

### Installation

You can install in development mode using `pip install -e .`

#### Requirements

##### Python
- Python >= 3.4

##### Core requirements
- numpy >= 1.14.3
- scipy >= 1.1.0
- pytest >= 3.7.3
- tqdm >= 4.26.0
- h5py >= 2.8.0
- packaging >= 17.1

##### Compatability
- deprecation >= 2.0.6
- typing >= 3.6.6

##### Coverage
- coverage >= 4.5.2
- codecov >= 2.0.15
- pytest-cov >= 2.6.1

##### Tensorflow
- tensorflow >= 1.12

### About the Name

Keras is Greek for 'horn', and rhinoceroses have horns, thus the name, rinokeras


